@@ -10,54 +10,28 @@ import java.util.List;
 import java.util.stream.Collectors;
 
 public class MassSpectrum implements MassSpectrumMetaInformation {
-    private String typ;
-    private String searchEngine;
     private List<Double> mz = new ArrayList<Double>();
     private List<Double> intensity = new ArrayList<Double>();
     private List<Integer> charge = new ArrayList<Integer>();
     private List<Double> isotope = new ArrayList<Double>();
     private double peptideMass;
-    private double rt;
     private int chargeState;
     private int id;
 
     public MassSpectrum() {
-        this.mz = new ArrayList<Double>();
-        this.intensity = new ArrayList<Double>();
-        this.charge = new ArrayList<Integer>();
-        this.isotope = new ArrayList<Double>();
-        this.typ = null;
-        this.searchEngine = null;
-        this.id = 0;
-        this.rt = 0;
-        this.chargeState = 0;
-        this.peptideMass = 0;
+        this(new ArrayList<Double>(), new ArrayList<Double>(), 0, 0, 0);
     }
 
     public MassSpectrum(List<Double> mz, List<Double> intensity) {
-        this(null, null, mz, intensity, 0, 0, 0, 0);
+        this(mz, intensity, 0, 0, 0);
     }
 
-    public MassSpectrum(String typ, String searchEngine, List<Double> mz, List<Double> intensity, double peptidMass,
-            double rt, int chargeState, int id) {
-        if (!isSorted(mz)) {
-            throw new IllegalArgumentException("The mZ-values are not sorted!");
-        }
-
-        this.mz = mz;
-        this.intensity = intensity;
-        this.charge = new ArrayList<Integer>();
-        this.isotope = new ArrayList<Double>();
-        this.typ = typ;
-        this.searchEngine = searchEngine;
-        this.id = id;
-        this.rt = rt;
-        this.chargeState = chargeState;
-        this.peptideMass = peptidMass;
+    public MassSpectrum(List<Double> mz, List<Double> intensity, double peptidMass, int chargeState, int id) {
+        this(mz, intensity, peptidMass, chargeState, id, new ArrayList<Integer>(), new ArrayList<Double>());
     }
 
-    public MassSpectrum(String typ, String searchEngine, List<Double> mz, List<Double> intensity, double peptidMass,
-            double rt, int chargeState, int id, List<Integer> charge, List<Double> isotope) {
+    public MassSpectrum(List<Double> mz, List<Double> intensity, double peptidMass, int chargeState, int id,
+            List<Integer> charge, List<Double> isotope) {
         if (!isSorted(mz)) {
             throw new IllegalArgumentException("The mZ-values are not sorted!");
         }
@@ -66,10 +40,7 @@ public class MassSpectrum implements MassSpectrumMetaInformation {
         this.intensity = intensity;
         this.charge = charge;
         this.isotope = isotope;
-        this.typ = typ;
-        this.searchEngine = searchEngine;
         this.id = id;
-        this.rt = rt;
         this.chargeState = chargeState;
         this.peptideMass = peptidMass;
     }
@@ -122,14 +93,6 @@ public class MassSpectrum implements MassSpectrumMetaInformation {
         return id;
     }
 
-    public String getTyp() {
-        return typ;
-    }
-
-    public String getSearchEngine() {
-        return searchEngine;
-    }
-
     public double getPeptideMass() {
         return peptideMass;
     }
@@ -138,10 +101,6 @@ public class MassSpectrum implements MassSpectrumMetaInformation {
         this.peptideMass = peptidMass;
     }
 
-    public double getRt() {
-        return rt;
-    }
-
     public int getChargeState() {
         return chargeState;
     }
