@@ -14,32 +14,27 @@ import java.util.Set;
 
 import ch.fgcz.proteomics.utilities.MathUtils;
 
-// TODO: Fix id's of clusters...
-
 public class IsotopicSet {
     private final PeakList peakList;
-    private List<IsotopicCluster> isotopicSet = null;
+    private List<IsotopicCluster> iSet = null;
     private List<IsotopicCluster> bestPath = null;
     private List<Peak> peaksInSet = null;
     private String dot = null;
     private int setId;
 
     public IsotopicSet(PeakList peakList, List<Peak> peaksInSet, int setId, Configuration config) {
-
         this.peakList = peakList;
         rangeCheck(peaksInSet, config);
 
         this.peaksInSet = peaksInSet;
+        this.setId = setId;
+        List<IsotopicCluster> tempIsotopicSet = collectClusters(config, peaksInSet);
 
-        List<IsotopicCluster> tempIsotopicSet = collectClusters(config, setId);
-
-        this.isotopicSet = tempIsotopicSet;
+        this.iSet = tempIsotopicSet;
         setBestPath(peakList, tempIsotopicSet, config);
     }
 
-    // TODO Looks to me like an isotopicSet method.
-    static public PeakList checkForCorrectRangeOfPeaks(PeakList peakList, Configuration config)
-            throws IllegalArgumentException {
+    public static PeakList checkForCorrectRangeOfPeaks(PeakList peakList, Configuration config) {
         if (peakList.isSortedByMass()) {
             // first check if sorted.
             // do we want to limit us to charge 3?
@@ -53,10 +48,9 @@ public class IsotopicSet {
                             config.getDelta())) {
                         b = true;
                     }
-
                 }
 
-                if (b == false) {
+                if (!b) {
                     return null;
                 }
             }
@@ -80,7 +74,7 @@ public class IsotopicSet {
     }
 
     public List<IsotopicCluster> getIsotopicSet() {
-        return isotopicSet;
+        return iSet;
     }
 
     public String getDot() {
@@ -98,24 +92,58 @@ public class IsotopicSet {
         return bestClusters;
     }
 
-    private List<IsotopicCluster> collectClusters(Configuration config, int setId) {
-        List<IsotopicCluster> isotopicClusters = new ArrayList<IsotopicCluster>();
+    // TODO (LS) not sure if should not moved to isotopicSet. LS: is moved
+    protected static List<IsotopicCluster> removeOverlappingPeaksInClusters(List<IsotopicCluster> isotopicClusters) {
+        // If cluster has same peak/peaks as other cluster.
+        // Remove this peak in the lowest charged cluster.
+        // Aggregate only the non removed cluster and add the remaining peaks from the
+        // overlapping cluster to the resultPeakList.
 
-        for (int charge = 3; 0 < charge; charge--) {
-            isotopicClusters = collectClusterForEachCharge(isotopicClusters, this.peaksInSet, charge, config);
+        for (IsotopicCluster isotopicCluster1 : isotopicClusters) {
+            for (IsotopicCluster isotopicCluster2 : isotopicClusters) {
+                if (isotopicCluster1.equals(isotopicCluster2)) {
+                    continue;
+                }
+
+                if (isotopicCluster1.hasSamePeaks(isotopicCluster2)) {
+                    isotopicCluster1.manipulateWhenHasSamePeaks(isotopicCluster2);
+                }
+            }
+        }
+        return isotopicClusters;
+    }
+
+    // TODO : write a few tests.
+    protected static List<IsotopicCluster> removeDoubleClusterLeaveTripleCluster(
+            List<IsotopicCluster> isotopicClusters) {
+        List<IsotopicCluster> isotopicClusters2 = new ArrayList<IsotopicCluster>();
+
+        for (IsotopicCluster cluster1 : isotopicClusters) {
+            for (IsotopicCluster cluster2 : isotopicClusters) {
+                innerIfStatementsOfRemoveDoubleCluster(isotopicClusters2, cluster1, cluster2);
+            }
         }
 
-        isotopicClusters = removeMultipleIsotopicCluster(isotopicClusters);
-
-        isotopicClusters = sortIsotopicSet(isotopicClusters);
-
-        this.setId = setId;
-
-        isotopicClusters = setPositions(isotopicClusters);
+        isotopicClusters.removeAll(removeMultipleIsotopicCluster(isotopicClusters2));
 
         return isotopicClusters;
     }
 
+    private List<IsotopicCluster> collectClusters(Configuration config, List<Peak> peaksInSet) {
+
+        List<IsotopicCluster> isotopicClusters = new ArrayList<IsotopicCluster>();
+        for (int charge = 3; 0 < charge; charge--) {
+            collectClusterForEachCharge(isotopicClusters, peaksInSet, charge, config);
+        }
+
+        isotopicClusters = removeMultipleIsotopicCluster(isotopicClusters);
+        sortIsotopicSet(isotopicClusters);
+        setPositions(isotopicClusters);
+
+        return isotopicClusters;
+    }
+
+    // TODO: Fix id's of clusters...
     private List<IsotopicCluster> setPositions(List<IsotopicCluster> isotopicClusters) {
         int clusterId = 0;
         for (IsotopicCluster isotopicCluster : isotopicClusters) {
@@ -128,7 +156,7 @@ public class IsotopicSet {
                 int position = 1;
                 for (Peak peak : isotopicCluster.getIsotopicCluster()) {
                     peak.setIsotopicSetID(setId);
-                    peak.setIsotopicClusterID(isotopicCluster.getClusterID());
+                    // peak.setIsotopicClusterID(isotopicCluster.getClusterID());
                     peak.setIsotope(position);
                     position++;
                 }
@@ -142,50 +170,20 @@ public class IsotopicSet {
         // FIRST GRAPH AND BEST PATH
         List<IsotopicCluster> isotopicClustersForBestPath = new ArrayList<IsotopicCluster>(isotopicClusters);
 
-        IsotopicClusterGraph isotopicClusterGraphForBestPath = new IsotopicClusterGraph(
-                removeDoubleClusterLeaveTripleCluster(isotopicClustersForBestPath));
+        IsotopicSetGraph isotopicSetGraphForBestPath = new IsotopicSetGraph(
+                removeDoubleClusterLeaveTripleCluster(isotopicClustersForBestPath), peaklist, peaklist.getPeptideMass(),
+                peaklist.getChargeState(), config);
 
-        isotopicClusterGraphForBestPath.scoreIsotopicClusterGraph(peaklist.getPeptideMass(), peaklist.getChargeState(),
-                peaklist, config);
-
-        this.bestPath = isotopicClusterGraphForBestPath
-                .bestPath(isotopicClusterGraphForBestPath.getStart(), isotopicClusterGraphForBestPath.getEnd())
-                .getVertexList();
+        this.bestPath = isotopicSetGraphForBestPath
+                .bestPath(isotopicSetGraphForBestPath.getStart(), isotopicSetGraphForBestPath.getEnd()).getVertexList();
 
         // THEN GRAPH AND DOT
         List<IsotopicCluster> isotopicClustersForDot = new ArrayList<IsotopicCluster>(isotopicClusters);
 
-        IsotopicClusterGraph isotopicClusterGraphForDot = new IsotopicClusterGraph(isotopicClustersForDot);
+        IsotopicSetGraph isotopicSetGraph = new IsotopicSetGraph(isotopicClustersForDot, peaklist,
+                peaklist.getPeptideMass(), peaklist.getChargeState(), config);
 
-        isotopicClusterGraphForDot.scoreIsotopicClusterGraph(peaklist.getPeptideMass(), peaklist.getChargeState(),
-                peaklist, config);
-
-        this.dot = isotopicClusterGraphForDot.toDOTGraph();
-    }
-
-    private List<IsotopicCluster> removeDoubleClusterLeaveTripleCluster(List<IsotopicCluster> isotopicClusters) {
-        List<IsotopicCluster> isotopicClusters2 = new ArrayList<IsotopicCluster>();
-
-        for (IsotopicCluster cluster1 : isotopicClusters) {
-            for (IsotopicCluster cluster2 : isotopicClusters) {
-                if (cluster1.size() == 3 && cluster2.size() == 2) {
-                    if (cluster1.getPeak(1).equals(cluster2.getPeak(0))
-                            && cluster1.getPeak(2).equals(cluster2.getPeak(1))) {
-                        isotopicClusters2.add(cluster2);
-                    }
-                }
-                if (cluster1.size() == 2 && cluster2.size() == 3) {
-                    if (cluster1.getPeak(0).equals(cluster2.getPeak(0))
-                            && cluster1.getPeak(1).equals(cluster2.getPeak(1))) {
-                        isotopicClusters2.add(cluster1);
-                    }
-                }
-            }
-        }
-
-        isotopicClusters.removeAll(removeMultipleIsotopicCluster(isotopicClusters2));
-
-        return isotopicClusters;
+        this.dot = IsotopicSetGraphToDotGraph.toDOTGraph(isotopicSetGraph.getIsotopicClusterGraph());
     }
 
     private List<IsotopicCluster> collectClusterForEachCharge(List<IsotopicCluster> isotopicClusters,
@@ -194,31 +192,14 @@ public class IsotopicSet {
             for (Peak b : isotopicSet) {
                 double distanceab = b.getMz() - a.getMz();
                 for (Peak c : isotopicSet) {
-                    List<Peak> ic = new ArrayList<Peak>();
-                    double distanceac = c.getMz() - a.getMz();
-                    double distancebc = c.getMz() - b.getMz();
-
-                    if ((config.getIsotopicPeakDistance() / charge) - config.getDelta() < distanceab
-                            && distanceab < (config.getIsotopicPeakDistance() / charge) + config.getDelta()) {
-                        a.setCharge(charge);
-                        b.setCharge(charge);
-                        ic.add(a);
-                        ic.add(b);
-                    }
-
-                    if ((config.getIsotopicPeakDistance() / charge) - config.getDelta() < distancebc
-                            && distancebc < (config.getIsotopicPeakDistance() / charge) + config.getDelta()
-                            && ((config.getIsotopicPeakDistance() / charge) - config.getDelta()) * 2 < distanceac
-                            && distanceac < ((config.getIsotopicPeakDistance() / charge) + config.getDelta()) * 2) {
-                        c.setCharge(charge);
-                        ic.add(c);
-                    }
 
+                    List<Peak> ic = innerIfStatementsOfCollectCluster(a, b, c, charge, config, distanceab);
                     if (ic.size() == 2 || ic.size() == 3) {
                         IsotopicCluster cluster = new IsotopicCluster(ic, charge, this.peakList,
                                 config.getIsotopicPeakDistance(), config.getDelta());
                         isotopicClusters.add(cluster);
                     }
+
                 }
             }
         }
@@ -226,6 +207,41 @@ public class IsotopicSet {
         return isotopicClusters;
     }
 
+    private static void innerIfStatementsOfRemoveDoubleCluster(List<IsotopicCluster> isotopicClusters,
+            IsotopicCluster cluster1, IsotopicCluster cluster2) {
+        if (cluster1.size() == 3 && cluster2.size() == 2 && (cluster1.getPeak(1).equalsPeak(cluster2.getPeak(0))
+                && cluster1.getPeak(2).equalsPeak(cluster2.getPeak(1)))) {
+            isotopicClusters.add(cluster2);
+        } else if (cluster1.size() == 2 && cluster2.size() == 3 && (cluster1.getPeak(0).equalsPeak(cluster2.getPeak(0))
+                && cluster1.getPeak(1).equalsPeak(cluster2.getPeak(1)))) {
+            isotopicClusters.add(cluster1);
+        }
+    }
+
+    private static List<Peak> innerIfStatementsOfCollectCluster(Peak a, Peak b, Peak c, int charge,
+            Configuration config, double distanceab) {
+        List<Peak> ic = new ArrayList<Peak>();
+        double distanceac = c.getMz() - a.getMz();
+        double distancebc = c.getMz() - b.getMz();
+
+        if ((config.getIsotopicPeakDistance() / charge) - config.getDelta() < distanceab
+                && distanceab < (config.getIsotopicPeakDistance() / charge) + config.getDelta()) {
+            a.setCharge(charge);
+            b.setCharge(charge);
+            ic.add(a);
+            ic.add(b);
+        }
+
+        if ((config.getIsotopicPeakDistance() / charge) - config.getDelta() < distancebc
+                && distancebc < (config.getIsotopicPeakDistance() / charge) + config.getDelta()
+                && ((config.getIsotopicPeakDistance() / charge) - config.getDelta()) * 2 < distanceac
+                && distanceac < ((config.getIsotopicPeakDistance() / charge) + config.getDelta()) * 2) {
+            c.setCharge(charge);
+            ic.add(c);
+        }
+        return (ic);
+    }
+
     private static List<IsotopicCluster> removeMultipleIsotopicCluster(List<IsotopicCluster> isotopicClusters) {
         List<IsotopicCluster> result = new ArrayList<IsotopicCluster>();
         Set<List<Peak>> set = new HashSet<List<Peak>>();
@@ -245,13 +261,13 @@ public class IsotopicSet {
 
             boolean b = false;
             for (int charge = 1; charge <= 3; charge++) {
-                if (((config.getIsotopicPeakDistance() / charge - config.getDelta() < Math.abs(distance)
-                        && Math.abs(distance) < config.getIsotopicPeakDistance() / charge + config.getDelta()))) {
+                if ((config.getIsotopicPeakDistance() / charge - config.getDelta() < Math.abs(distance)
+                        && Math.abs(distance) < config.getIsotopicPeakDistance() / charge + config.getDelta())) {
                     b = true;
                 }
             }
 
-            if (b == false) {
+            if (!b) {
                 throw new IllegalArgumentException("Wrong distance at IsotopicSet creation! (" + distance + ")");
             }
         }
@@ -265,11 +281,9 @@ public class IsotopicSet {
 
                 if (result == 0) {
                     result = Double.compare(cluster1.getPeak(1).getMz(), cluster2.getPeak(1).getMz());
-                    if (result == 0) {
-                        if (cluster1.size() == 3 && cluster2.size() == 3) {
-                            result = Double.compare(cluster1.getPeak(2).getMz(), cluster2.getPeak(2).getMz());
-                            return result;
-                        }
+                    if (result == 0 && (cluster1.size() == 3 && cluster2.size() == 3)) {
+                        result = Double.compare(cluster1.getPeak(2).getMz(), cluster2.getPeak(2).getMz());
+                        return result;
                     }
                 }
 
