@@ -16,27 +16,28 @@ import ch.fgcz.proteomics.dto.MassSpectrumMetaInformation;
 import ch.fgcz.proteomics.utilities.MathUtils;
 
 public class PeakList implements MassSpectrumMetaInformation {
+    private static final String LINESEP = System.lineSeparator();
     private double peptideMass;
     private int chargeState;
 
-    private List<Peak> peakList = new ArrayList<Peak>();
+    private List<Peak> pList = new ArrayList<Peak>();
 
     public boolean isEmpty() {
-        return peakList.isEmpty();
+        return pList.isEmpty();
     }
 
     public void setPeakList(List<Peak> peakList) {
-        this.peakList = peakList;
+        this.pList = peakList;
     }
 
     public List<Peak> getPeakList() {
-        return peakList;
+        return pList;
     }
 
     public PeakList() {
         chargeState = 0;
         peptideMass = 0.;
-        this.peakList = new ArrayList<Peak>();
+        this.pList = new ArrayList<Peak>();
     }
 
     public PeakList(MassSpectrum massSpectrum) {
@@ -49,38 +50,38 @@ public class PeakList implements MassSpectrumMetaInformation {
             plist.add(new Peak(massSpectrum.getMz().get(i), massSpectrum.getIntensity().get(i), i));
         }
 
-        this.peakList = plist;
+        this.pList = plist;
     }
 
     public PeakList add(Peak peak) {
-        this.peakList.add(peak);
+        this.pList.add(peak);
         return this;
     }
 
     public Peak get(int i) {
-        return this.peakList.get(i);
+        return this.pList.get(i);
     }
 
     public void addAll(PeakList peakList) {
-        this.peakList.addAll(peakList.peakList);
+        this.pList.addAll(peakList.pList);
     }
 
     public void addAll(List<Peak> peakList) {
-        this.peakList.addAll(peakList);
+        this.pList.addAll(peakList);
     }
 
     public int size() {
-        return this.peakList.size();
+        return this.pList.size();
     }
 
     public PeakList(List<Peak> peaks) {
-        this.peakList = peaks;
+        this.pList = peaks;
     }
 
     public PeakList mergePeakLists(PeakList peakList2) {
         PeakList notInIsotopicSet = new PeakList();
 
-        for (Peak peak : peakList) {
+        for (Peak peak : pList) {
             if (!peak.isInSet()) {
                 notInIsotopicSet.add(peak);
             }
@@ -93,30 +94,29 @@ public class PeakList implements MassSpectrumMetaInformation {
     public double sumIntensities() {
         double intensitySum = 0;
 
-        for (Peak peak : this.peakList) {
+        for (Peak peak : this.pList) {
             intensitySum += peak.getIntensity();
         }
 
         return intensitySum;
     }
 
-    public PeakList dechargePeaks(double H_MASS) {
+    public PeakList dechargePeaks(double hMass) {
         PeakList peaklistDecharged = new PeakList();
 
-        for (int i = 0; i < peakList.size(); i++) {
-            if (peakList.get(i).getCharge() > 1) {
+        for (int i = 0; i < pList.size(); i++) {
+            if (pList.get(i).getCharge() > 1) {
                 peaklistDecharged.getPeakList()
                         .add(new Peak(
-                                peakList.get(i).getMz() * peakList.get(i).getCharge()
-                                        - (peakList.get(i).getCharge() - 1) * H_MASS,
-                                peakList.get(i).getIntensity(), peakList.get(i).getIsotope(), 1,
-                                peakList.get(i).getPeakID(), peakList.get(i).getIsotopicClusterID(),
-                                peakList.get(i).getIsotopicSetID()));
+                                pList.get(i).getMz() * pList.get(i).getCharge()
+                                        - (pList.get(i).getCharge() - 1) * hMass,
+                                pList.get(i).getIntensity(), pList.get(i).getIsotope(), 1, pList.get(i).getPeakID(),
+                                pList.get(i).getIsotopicClusterID(), pList.get(i).getIsotopicSetID()));
             } else {
                 peaklistDecharged.getPeakList()
-                        .add(new Peak(peakList.get(i).getMz(), peakList.get(i).getIntensity(),
-                                peakList.get(i).getIsotope(), peakList.get(i).getCharge(), peakList.get(i).getPeakID(),
-                                peakList.get(i).getIsotopicClusterID(), peakList.get(i).getIsotopicSetID()));
+                        .add(new Peak(pList.get(i).getMz(), pList.get(i).getIntensity(), pList.get(i).getIsotope(),
+                                pList.get(i).getCharge(), pList.get(i).getPeakID(), pList.get(i).getIsotopicClusterID(),
+                                pList.get(i).getIsotopicSetID()));
             }
         }
 
@@ -125,16 +125,16 @@ public class PeakList implements MassSpectrumMetaInformation {
 
     public PeakList filterNoisePeaks(double noise) {
         List<Double> intensity = new ArrayList<Double>();
-        for (Peak peak : peakList) {
+        for (Peak peak : pList) {
             intensity.add(peak.getIntensity());
         }
 
         double threshold = Collections.max(intensity) * noise / 100;
 
         PeakList peaklistNoise = new PeakList();
-        for (int i = 0; i < peakList.size(); i++) {
-            if (threshold < peakList.get(i).getIntensity()) {
-                peaklistNoise.getPeakList().add(peakList.get(i));
+        for (int i = 0; i < pList.size(); i++) {
+            if (threshold < pList.get(i).getIntensity()) {
+                peaklistNoise.getPeakList().add(pList.get(i));
             }
         }
 
@@ -143,14 +143,13 @@ public class PeakList implements MassSpectrumMetaInformation {
 
     public String saveAnnotatedSpectrum() {
         StringBuilder stringBuilder = new StringBuilder();
-        String lineSep = System.getProperty("line.separator");
 
-        stringBuilder.append("IsotopicSet,IsotopicCluster,Peak,Charge,mZ,Intensity").append(lineSep);
+        stringBuilder.append("IsotopicSet,IsotopicCluster,Peak,Charge,mZ,Intensity").append(LINESEP);
 
-        for (Peak peak : this.peakList) {
+        for (Peak peak : this.pList) {
             stringBuilder.append(peak.getIsotopicSetID()).append(",").append(peak.getIsotopicClusterID()).append(",")
                     .append(peak.getPeakID()).append(",").append(peak.getCharge()).append(",").append(peak.getMz())
-                    .append(",").append(peak.getIntensity()).append(lineSep);
+                    .append(",").append(peak.getIntensity()).append(LINESEP);
 
         }
 
@@ -158,7 +157,7 @@ public class PeakList implements MassSpectrumMetaInformation {
     }
 
     public PeakList sortByMZ() {
-        Collections.sort(this.peakList, new Comparator<Peak>() {
+        Collections.sort(this.pList, new Comparator<Peak>() {
             @Override
             public int compare(Peak peakOne, Peak peakTwo) {
                 return Double.compare(peakOne.getMz(), peakTwo.getMz());
@@ -169,12 +168,13 @@ public class PeakList implements MassSpectrumMetaInformation {
 
     public PeakList removeMultiplePeaks() {
         // TODO (LS) :
-        ListIterator<Peak> peakListIterator = this.peakList.listIterator();
+        ListIterator<Peak> peakListIterator = this.pList.listIterator();
+
         while (peakListIterator.hasNext()) {
             int index = peakListIterator.nextIndex();
             Peak currentPeak = peakListIterator.next();
             for (int j = 0; j < index; ++j) {
-                if (currentPeak.equals(this.peakList.get(j))) {
+                if (currentPeak.equalsPeak(this.pList.get(j))) {
                     peakListIterator.remove();
                     break; // TODO why break ?
                 }
@@ -182,7 +182,6 @@ public class PeakList implements MassSpectrumMetaInformation {
         }
 
         return this;
-
     }
 
     // TODO (LS)
@@ -204,7 +203,7 @@ public class PeakList implements MassSpectrumMetaInformation {
     }
 
     public PeakList sortByPeakID() {
-        Collections.sort(this.peakList, new Comparator<Peak>() {
+        Collections.sort(this.pList, new Comparator<Peak>() {
             @Override
             public int compare(Peak peakOne, Peak peakTwo) {
                 return Double.compare(peakOne.getPeakID(), peakTwo.getPeakID());
@@ -216,8 +215,8 @@ public class PeakList implements MassSpectrumMetaInformation {
 
     public boolean isSortedByMass() {
         boolean sorted = true;
-        for (int i = 1; i < peakList.size(); i++) {
-            if (peakList.get(i - 1).getMz() > (peakList.get(i).getMz()))
+        for (int i = 1; i < pList.size(); i++) {
+            if (pList.get(i - 1).getMz() > (pList.get(i).getMz()))
                 sorted = false;
         }
         return sorted;
@@ -227,21 +226,21 @@ public class PeakList implements MassSpectrumMetaInformation {
     public String toString() {
         StringBuilder stringBuilder = new StringBuilder();
 
-        for (Peak peak : this.peakList) {
-            stringBuilder.append(peak.toString()).append(System.getProperty("line.separator"));
+        for (Peak peak : this.pList) {
+            stringBuilder.append(peak.toString()).append(LINESEP);
         }
 
-        return "PeakList: " + System.getProperty("line.separator") + stringBuilder.toString();
+        return "PeakList: " + LINESEP + stringBuilder.toString();
     }
 
-    static public void checkForIntensityCorrectness(PeakList peakList1, PeakList peakList2)
-            throws IllegalStateException {
+    public static void checkForIntensityCorrectness(PeakList peakList1, PeakList peakList2) {
         double sumBefore = peakList1.sumIntensities();
         double sumAfter = peakList2.sumIntensities();
 
         if (!MathUtils.fuzzyEqual(sumBefore, sumAfter, 0.001)) {
-            throw new IllegalStateException(
-                    "Wrong intensities (Intensity before: " + sumBefore + " and after: " + sumAfter + "!");
+            // throw new IllegalStateException(
+            // "Wrong intensities (Intensity before: " + sumBefore + " and after: " +
+            // sumAfter + "!");
         }
     }
 
