@@ -10,22 +10,25 @@ import java.util.List;
 
 import ch.fgcz.proteomics.dto.MassSpectrum;
 
+/**
+ * @deprecated isn't up to date anymore.
+ */
 @Deprecated
 public class Peaklist {
-    private List<Peak> peaklist = new ArrayList<Peak>();
+    private List<Peak> pList = new ArrayList<Peak>();
 
     public List<Peak> getPeaklist() {
-        return peaklist;
+        return pList;
     }
 
     public void setPeaklist(List<Peak> peaklist) {
-        this.peaklist = peaklist;
+        this.pList = peaklist;
     }
 
     public Peaklist(MassSpectrum ms) {
         List<Peak> plist = new ArrayList<Peak>();
 
-        if (ms.getCharge().size() != 0 && ms.getIsotope().size() != 0) {
+        if (!ms.getCharge().isEmpty() && !ms.getIsotope().isEmpty()) {
             for (int i = 0; i < ms.getMz().size() || i < ms.getIntensity().size(); i++) {
                 plist.add(new Peak(ms.getMz().get(i), ms.getIntensity().get(i), ms.getIsotope().get(i),
                         ms.getCharge().get(i)));
@@ -36,7 +39,7 @@ public class Peaklist {
             }
         }
 
-        this.peaklist = plist;
+        this.pList = plist;
     }
 
     public Peaklist(List<Double> mz, List<Double> intensity) {
@@ -46,7 +49,7 @@ public class Peaklist {
             plist.add(new Peak(mz.get(i), intensity.get(i)));
         }
 
-        this.peaklist = plist;
+        this.pList = plist;
     }
 
     public Peaklist(List<Double> mz, List<Double> intensity, List<Integer> charge, List<Double> isotope) {
@@ -56,6 +59,6 @@ public class Peaklist {
             plist.add(new Peak(mz.get(i), intensity.get(i), isotope.get(i), charge.get(i)));
         }
 
-        this.peaklist = plist;
+        this.pList = plist;
     }
 }
